@@ -1,5 +1,7 @@
 api_version = 2.13
+admin_api_version = 1.0
 context_path = 'caas'
+admin_path = 'admin'
 my_user_path = '/user/myUser'
 list_servers = '/server/server'
 get_server = '/server/server/{0}'
@@ -9,6 +11,7 @@ list_datacenters = '/infrastructure/datacenter'
 list_geos = '/infrastructure/geographicRegion'
 list_os_image = '/image/osImage/'
 list_customer_image = '/image/customerImage/'
+get_organization_summary = '/customer/organization/{0}'
 
 known_geos = ['africa', 'asiapacific', 'australia', 'canada', 'europe', 'indonesia', 'israel', 'northamerica']
 
